# -*- coding: utf-8 -*-

"""
This module contains usefull functions commons to every modules
"""

import logging
import pathlib
from pathlib import Path
from itertools import zip_longest
import enum
import re
import fiona
from pathlib import Path
from datetime import datetime
from pprint import pprint


logger = logging.getLogger(__name__)
logging.basicConfig(level=logging.INFO)


DATES_FORMATS = dict(
    ymd = "%Y-%m-%d",
    filename = "%Y%m%dT%H%M%S",
    metadata = "%Y-%m-%dT%H:%M:%S.%fZ")


def format_word(word: str) -> str:
    """Format word to lower case and removes heading and trailing spaces.

    :param word: a string to format.
    """
    if not isinstance(word, str):
        raise TypeError("word has to be a string")
    return word.lower().strip()


def grouper(iterable, n: int, fillvalue: bool=None):
    """Collects data into fixed-length chunks or blocks.

    :param iterable:
    :param n:
    :param fillvalue:
    """
    args = [iter(iterable)] * n
    return zip_longest(*args, fillvalue=fillvalue)


def str_to_datetime(date_string: str, date_format: str) -> datetime:
    """Returns.

    :param date_string:
    :param date_format:
    """
    try:
        date_format = DATES_FORMATS.get(date_format)
    except KeyError:
        raise ValueError("Invalid date format")
    return datetime.strptime(date_string, date_format)


def datetime_to_str(date: datetime, date_format: str) -> str:
    """Returns.

    :param date:
    :param date_format:
    """
    try:
        date_format = DATES_FORMATS.get(date_format)
    except KeyError:
        raise ValueError("Invalid date format")
    return datetime.strftime(date, date_format)
